@@ -1,5 +1,5 @@
 listOrganism <- function(hostName="http://www.webgestalt.org/"){
-	json_data <- fromJSON(file=paste(hostName,"/data/idtypesummary.json",sep=""))
+	json_data <- fromJSON(file=file.path(hostName,"data","idtypesummary.json"))
 	organisms <- names(json_data)
   return(organisms)
 }
\ No newline at end of file
